@@ -1,10 +1,10 @@
 ##
 ## Representation for AS events
 ##
-import json_utils
-import pickle_utils
-import Gene
-import as_events
+import misopy
+import misopy.json_utils as json_utils
+import misopy.pickle_utils as pickle_utils
+import misopy.Gene as Gene
 import time
 import csv
 import os
